@@ -21,7 +21,7 @@
 
 #include <stdlib.h>
 
-#include <gtkmm.h>
+#include <gtkmm/main.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
